/**
 * 
 * This class is part of the Preclipse Tutorial 
 * 
 * http://www.preclipse.de/
 * 
 * This program and the accompanying materials are made
 * available under the terms of the General Public License 
 * which accompanies this distribution.
 * 
 */
package de.preclipse.DVDStorage.gui;
import java.io.IOException;
import java.util.List;

/**
 * 
 * Interface between GUI and the rest of the system.
 * 
 * @author Preclipse Team
 * 
 */
public interface DVDStorageGUIActionListener {
	

	/**
	 * 
	 * Adds a new DVD to the system.
	 * 
	 * @param name Name of the movie
	 * @param year Year the movie was shot
	 * @param length Running time in minutes
	 * @param imdb IMDB identification number
	 * @param comment Your personal comment about the movie
	 * @throws Exception 
	 */
	public void newDVDAction(String name, int year, int len, String imdb,
			String comment) throws Exception;
	
	/**
	 * 
	 * Changes a DVD in the system.
	 * 
	 * @param ID ID of the DVD in question
	 * @param name New name of the movie
	 * @param year New year the movie was shot
	 * @param length New running time in minutes
	 * @param imdb New IMDB identification number
	 * @param comment New personal comment
	 */
	public void changeDVDAction(long ID, String name, int year, int len,
			String imdb, String comment) throws Exception;
	
	/**
	 * 
	 * Deletes a DVD from the system
	 * 
	 * @param ID ID of the DVD
	 */
	public void deleteAction(long ID);
	
	/**
	 * 
	 * Takes a snapshot.
	 * 
	 * @throws IOException
	 */
	public void snapshotAction() throws IOException;
	
	/**
	 * 
	 * Returns the list of DVDs for displaying purposes.
	 * 
	 * @return List of DVDs
	 */
	public List getDVDList();
}